/////////////////////////////
//  global.h               //
//  2008/01/15             //
/////////////////////////////

#ifndef _GLOBAL_H
#define _GLOBAL_H

///// CPU Type
#include <p18f1320.h>

///// ^̒Zk
typedef unsigned char uchar;
typedef unsigned int uint;
typedef unsigned long ulong;

///// delay
#include <delays.h>
#define CONFIG_MHZ 8

extern void delay_ms( uint);

///// LCD
#define		lcd_port	LATB
#define		lcd_stb		LATBbits.LATB5
#define		lcd_rs		LATBbits.LATB4

extern void lcd_init(void);
extern void lcd_clear(void);
extern void lcd_cmd(char);
extern void lcd_data(char);
extern void lcd_str(char *);
extern void lcd_str_rom(rom const char *);

///// Timer
#define TIMER_NUM 8

#define TIMER_IN_POLL		0
#define TIMER_SCAN		1
#define TIMER_SET_CANCEL	2
#define TIMER_LED			3
#define TIMER_E2WRITE		4

extern volatile uint tics;

extern void timer_init(void);
extern void timer_start(int, uint);
extern void timer_restart(int, uint);
extern void timer_cancel(int);
extern int timer_check(int);
extern int timer_check_start(int);

///// Input
extern volatile uchar constH;
extern volatile uchar constL;
extern volatile uchar cnt_DOWN;
extern volatile uchar cnt_UP;
extern volatile uchar cnt_ENT;
extern volatile uchar cnt_MODE;

typedef struct {
  unsigned _DOWN:1;
  unsigned _UP:1;
  unsigned _ENT:1;
  unsigned _MODE:1;
  unsigned _DOWN_L:1;
  unsigned _UP_L:1;
  unsigned _ENT_L:1;
  unsigned _MODE_L:1;
} INSWBITS;

extern INSWBITS INSWbits;

#define DOWN		INSWbits._DOWN
#define UP		INSWbits._UP
#define ENT		INSWbits._ENT
#define MODE		INSWbits._MODE
#define DOWN_L	INSWbits._DOWN_L
#define UP_L		INSWbits._UP_L
#define ENT_L		INSWbits._ENT_L
#define MODE_L	INSWbits._MODE_L

typedef struct {
  unsigned _DOWN_P:1;
  unsigned _UP_P:1;
  unsigned _ENT_P:1;
  unsigned _MODE_P:1;
  unsigned _DOWN_N:1;
  unsigned _UP_N:1;
  unsigned _ENT_N:1;
  unsigned _MODE_N:1;
} INSTBITS;

extern INSTBITS INSTbits;

#define DOWN_P	INSTbits._DOWN_P
#define UP_P		INSTbits._UP_P
#define ENT_P		INSTbits._ENT_P
#define MODE_P	INSTbits._MODE_P
#define DOWN_N	INSTbits._DOWN_N
#define UP_N		INSTbits._UP_N
#define ENT_N		INSTbits._ENT_N
#define MODE_N	INSTbits._MODE_N

extern void inp_init(void);
extern void input(void);

///// num_set
extern char set_point;

extern void lcd_num2d(char);
extern void num_init(void);
extern void num_set(void);


///// led
extern void led_init(void);
extern void led_on(void);


///// eeprom
extern char read_e2rom(uchar);
extern void write_e2rom(uchar, char);
extern void lock_e2rom(void);




#endif